_**by Edgar Allan Poe**  
(published 1850)_

    

_Nullus enim locus sine genio est._  
(No place is without its genius.)  
                                  _-- Servius_  
  
"LA MUSIQUE," says Marmontel, in those "Contes Moraux"* which in all our translations, we have insisted upon calling "Moral Tales," as if in mockery of their spirit -- "la musique est le seul des talents qui jouissent de lui-meme; tous les autres veulent des temoins." He here confounds the pleasure derivable from sweet sounds with the capacity for creating them. No more than any other talent, is that for music susceptible of complete enjoyment, where there is no second party to appreciate its exercise. And it is only in common with other talents that it produces effects which may be fully enjoyed in solitude. The idea which the raconteur has either failed to entertain clearly, or has sacrificed in its expression to his national love of point, is, doubtless, the very tenable one that the higher order of music is the most thoroughly estimated when we are exclusively alone. The proposition, in this form, will be admitted at once by those who love the lyre for its own sake, and for its spiritual uses. But there is one pleasure still within the reach of fallen mortality and perhaps only one -- which owes even more than does music to the accessory sentiment of seclusion. I mean the happiness experienced in the contemplation of natural scenery. In truth, the man who would behold aright the glory of God upon earth must in solitude behold that glory. To me, at least, the presence -- not of human life only, but of life in any other form than that of the green things which grow upon the soil and are voiceless -- is a stain upon the landscape -- is at war with the genius of the scene. I love, indeed, to regard the dark valleys, and the gray rocks, and the waters that silently smile, and the forests that sigh in uneasy slumbers, and the proud watchful mountains that look down upon all, -- I love to regard these as themselves but the colossal members of one vast animate and sentient whole -- a whole whose form (that of the sphere) is the most perfect and most inclusive of all; whose path is among associate planets; whose meek handmaiden is the moon, whose mediate sovereign is the sun; whose life is eternity, whose thought is that of a God; whose enjoyment is knowledge; whose destinies are lost in immensity, whose cognizance of ourselves is akin with our own cognizance of the animalculae which infest the brain -- a being which we, in consequence, regard as purely inanimate and material much in the same manner as these animalculae must thus regard us.  
  
* Moraux is here derived from moeurs, and its meaning is "fashionable" or more strictly "of manners."  
  
Our telescopes and our mathematical investigations assure us on every hand -- notwithstanding the cant of the more ignorant of the priesthood -- that space, and therefore that bulk, is an important consideration in the eyes of the Almighty. The cycles in which the stars move are those best adapted for the evolution, without collision, of the greatest possible number of bodies. The forms of those bodies are accurately such as, within a given surface, to include the greatest possible amount of matter; -- while the surfaces themselves are so disposed as to accommodate a denser population than could be accommodated on the same surfaces otherwise arranged. Nor is it any argument against bulk being an object with God, that space itself is infinite; for there may be an infinity of matter to fill it. And since we see clearly that the endowment of matter with vitality is a principle -- indeed, as far as our judgments extend, the leading principle in the operations of Deity, -- it is scarcely logical to imagine it confined to the regions of the minute, where we daily trace it, and not extending to those of the august. As we find cycle within cycle without end, -- yet all revolving around one far-distant centre which is the God-head, may we not analogically suppose in the same manner, life within life, the less within the greater, and all within the Spirit Divine? In short, we are madly erring, through self-esteem, in believing man, in either his temporal or future destinies, to be of more moment in the universe than that vast "clod of the valley" which he tills and contemns, and to which he denies a soul for no more profound reason than that he does not behold it in operation.*  
  
* Speaking of the tides, Pomponius Mela, in his treatise "De Situ Orbis," says "either the world is a great animal, or" etc.  
  
These fancies, and such as these, have always given to my meditations among the mountains and the forests, by the rivers and the ocean, a tinge of what the everyday world would not fail to term fantastic. My wanderings amid such scenes have been many, and far-searching, and often solitary; and the interest with which I have strayed through many a dim, deep valley, or gazed into the reflected Heaven of many a bright lake, has been an interest greatly deepened by the thought that I have strayed and gazed alone. What flippant Frenchman was it who said in allusion to the well-known work of Zimmerman, that, "la solitude est une belle chose; mais il faut quelqu'un pour vous dire que la solitude est une belle chose?" The epigram cannot be gainsayed; but the necessity is a thing that does not exist.  
  
It was during one of my lonely journeyings, amid a far distant region of mountain locked within mountain, and sad rivers and melancholy tarn writhing or sleeping within all -- that I chanced upon a certain rivulet and island. I came upon them suddenly in the leafy June, and threw myself upon the turf, beneath the branches of an unknown odorous shrub, that I might doze as I contemplated the scene. I felt that thus only should I look upon it -- such was the character of phantasm which it wore.  
  
On all sides -- save to the west, where the sun was about sinking -- arose the verdant walls of the forest. The little river which turned sharply in its course, and was thus immediately lost to sight, seemed to have no exit from its prison, but to be absorbed by the deep green foliage of the trees to the east -- while in the opposite quarter (so it appeared to me as I lay at length and glanced upward) there poured down noiselessly and continuously into the valley, a rich golden and crimson waterfall from the sunset fountains of the sky.  
  
About midway in the short vista which my dreamy vision took in, one small circular island, profusely verdured, reposed upon the bosom of the stream.  
  
So blended bank and shadow there  
  
That each seemed pendulous in air -- so mirror-like was the glassy water, that it was scarcely possible to say at what point upon the slope of the emerald turf its crystal dominion began.  
  
My position enabled me to include in a single view both the eastern and western extremities of the islet; and I observed a singularly-marked difference in their aspects. The latter was all one radiant harem of garden beauties. It glowed and blushed beneath the eyes of the slant sunlight, and fairly laughed with flowers. The grass was short, springy, sweet-scented, and Asphodel-interspersed. The trees were lithe, mirthful, erect -- bright, slender, and graceful, -- of eastern figure and foliage, with bark smooth, glossy, and parti-colored. There seemed a deep sense of life and joy about all; and although no airs blew from out the heavens, yet every thing had motion through the gentle sweepings to and fro of innumerable butterflies, that might have been mistaken for tulips with wings.*  
  
* Florem putares nare per liquidum aethera. -- P. Commire.  
  
The other or eastern end of the isle was whelmed in the blackest shade. A sombre, yet beautiful and peaceful gloom here pervaded all things. The trees were dark in color, and mournful in form and attitude, wreathing themselves into sad, solemn, and spectral shapes that conveyed ideas of mortal sorrow and untimely death. The grass wore the deep tint of the cypress, and the heads of its blades hung droopingly, and hither and thither among it were many small unsightly hillocks, low and narrow, and not very long, that had the aspect of graves, but were not; although over and all about them the rue and the rosemary clambered. The shade of the trees fell heavily upon the water, and seemed to bury itself therein, impregnating the depths of the element with darkness. I fancied that each shadow, as the sun descended lower and lower, separated itself sullenly from the trunk that gave it birth, and thus became absorbed by the stream; while other shadows issued momently from the trees, taking the place of their predecessors thus entombed.  
  
This idea, having once seized upon my fancy, greatly excited it, and I lost myself forthwith in revery. "If ever island were enchanted," said I to myself, "this is it. This is the haunt of the few gentle Fays who remain from the wreck of the race. Are these green tombs theirs? -- or do they yield up their sweet lives as mankind yield up their own? In dying, do they not rather waste away mournfully, rendering unto God, little by little, their existence, as these trees render up shadow after shadow, exhausting their substance unto dissolution? What the wasting tree is to the water that imbibes its shade, growing thus blacker by what it preys upon, may not the life of the Fay be to the death which engulfs it?"  
  
As I thus mused, with half-shut eyes, while the sun sank rapidly to rest, and eddying currents careered round and round the island, bearing upon their bosom large, dazzling, white flakes of the bark of the sycamore-flakes which, in their multiform positions upon the water, a quick imagination might have converted into any thing it pleased, while I thus mused, it appeared to me that the form of one of those very Fays about whom I had been pondering made its way slowly into the darkness from out the light at the western end of the island. She stood erect in a singularly fragile canoe, and urged it with the mere phantom of an oar. While within the influence of the lingering sunbeams, her attitude seemed indicative of joy -- but sorrow deformed it as she passed within the shade. Slowly she glided along, and at length rounded the islet and re-entered the region of light. "The revolution which has just been made by the Fay," continued I, musingly, "is the cycle of the brief year of her life. She has floated through her winter and through her summer. She is a year nearer unto Death; for I did not fail to see that, as she came into the shade, her shadow fell from her, and was swallowed up in the dark water, making its blackness more black."  
  
And again the boat appeared and the Fay, but about the attitude of the latter there was more of care and uncertainty and less of elastic joy. She floated again from out the light and into the gloom (which deepened momently) and again her shadow fell from her into the ebony water, and became absorbed into its blackness. And again and again she made the circuit of the island, (while the sun rushed down to his slumbers), and at each issuing into the light there was more sorrow about her person, while it grew feebler and far fainter and more indistinct, and at each passage into the gloom there fell from her a darker shade, which became whelmed in a shadow more black. But at length when the sun had utterly departed, the Fay, now the mere ghost of her former self, went disconsolately with her boat into the region of the ebony flood, and that she issued thence at all I cannot say, for darkness fell over an things and I beheld her magical figure no more.